spec
====
.. NOTE::
    This class is not intended for use by those using Pika in their applications. This documentation is for those who are extending Pika or otherwise working on the driver itself.

spec.py is an auto-generated python module which is created by the codegen.py application. It contains all of the information about the protocol that is required for Pika to communicate with RabbitMQ.

.. automodule:: spec
   :members:
   :inherited-members:
   :member-order: bysource
   :private-members: True
   :undoc-members:
